@@ -8,21 +8,19 @@ A handler can be bound to other types by calling
 
 """
 
-from __future__ import absolute_import, division, unicode_literals
-
 import array
 import copy
 import datetime
 import io
+import queue
 import re
-import sys
 import threading
 import uuid
 
-from . import compat, util
+from . import util
 
 
-class Registry(object):
+class Registry:
     def __init__(self):
         self._handlers = {}
         self._base_handlers = {}
@@ -70,7 +68,7 @@ class Registry(object):
 
             return _register
         if not util.is_type(cls):
-            raise TypeError('{!r} is not a class/type'.format(cls))
+            raise TypeError(f'{cls!r} is not a class/type')
         # store both the name and the actual type for the ugly cases like
         # _sre.SRE_Pattern that cannot be loaded back directly
         self._handlers[util.importable_name(cls)] = self._handlers[cls] = handler
@@ -90,7 +88,7 @@ unregister = registry.unregister
 get = registry.get
 
 
-class BaseHandler(object):
+class BaseHandler:
     def __init__(self, context):
         """
         Initialize a new handler to handle a registered type.
@@ -177,7 +175,7 @@ class DatetimeHandler(BaseHandler):
             if hasattr(obj, 'isoformat'):
                 result = obj.isoformat()
             else:
-                result = compat.ustr(obj)
+                result = str(obj)
             return result
         cls, args = obj.__reduce__()
         flatten = pickler.flatten
@@ -227,13 +225,13 @@ class QueueHandler(BaseHandler):
         return data
 
     def restore(self, data):
-        return compat.queue.Queue()
+        return queue.Queue()
 
 
-QueueHandler.handles(compat.queue.Queue)
+QueueHandler.handles(queue.Queue)
 
 
-class CloneFactory(object):
+class CloneFactory:
     """Serialization proxy for collections.defaultdict's default_factory"""
 
     def __init__(self, exemplar):
@@ -244,7 +242,7 @@ class CloneFactory(object):
         return clone(self.exemplar)
 
     def __repr__(self):
-        return '<CloneFactory object at 0x{:x} ({})>'.format(id(self), self.exemplar)
+        return f'<CloneFactory object at 0x{id(self):x} ({self.exemplar})>'
 
 
 class UUIDHandler(BaseHandler):
@@ -290,5 +288,4 @@ class TextIOHandler(BaseHandler):
         raise AssertionError('Restoring IO.TextIOHandler is not supported')
 
 
-if sys.version_info >= (3, 8):
-    TextIOHandler.handles(io.TextIOWrapper)
+TextIOHandler.handles(io.TextIOWrapper)
